lilypondfiletools.LilyPondFile
==============================

.. abjad-lineage:: abjad.tools.lilypondfiletools.LilyPondFile.LilyPondFile

.. autoclass:: abjad.tools.lilypondfiletools.LilyPondFile.LilyPondFile

.. only:: html

   Attribute summary
   -----------------

   .. autosummary::

      ~abjad.tools.lilypondfiletools.LilyPondFile.LilyPondFile.default_paper_size
      ~abjad.tools.lilypondfiletools.LilyPondFile.LilyPondFile.file_initial_system_comments
      ~abjad.tools.lilypondfiletools.LilyPondFile.LilyPondFile.file_initial_system_includes
      ~abjad.tools.lilypondfiletools.LilyPondFile.LilyPondFile.file_initial_user_comments
      ~abjad.tools.lilypondfiletools.LilyPondFile.LilyPondFile.file_initial_user_includes
      ~abjad.tools.lilypondfiletools.LilyPondFile.LilyPondFile.global_staff_size
      ~abjad.tools.lilypondfiletools.LilyPondFile.LilyPondFile.items
      ~abjad.tools.lilypondfiletools.LilyPondFile.LilyPondFile.use_relative_includes
      ~abjad.tools.lilypondfiletools.LilyPondFile.LilyPondFile.__eq__
      ~abjad.tools.lilypondfiletools.LilyPondFile.LilyPondFile.__format__
      ~abjad.tools.lilypondfiletools.LilyPondFile.LilyPondFile.__getitem__
      ~abjad.tools.lilypondfiletools.LilyPondFile.LilyPondFile.__hash__
      ~abjad.tools.lilypondfiletools.LilyPondFile.LilyPondFile.__illustrate__
      ~abjad.tools.lilypondfiletools.LilyPondFile.LilyPondFile.__ne__
      ~abjad.tools.lilypondfiletools.LilyPondFile.LilyPondFile.__repr__

Bases
-----

- :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject>`

- :py:class:`abctools.AbjadObject.AbstractBase <abjad.tools.abctools.AbjadObject.AbstractBase>`

- :py:class:`__builtin__.object <object>`

Read-only properties
--------------------

.. autoattribute:: abjad.tools.lilypondfiletools.LilyPondFile.LilyPondFile.file_initial_system_comments
   :noindex:

.. autoattribute:: abjad.tools.lilypondfiletools.LilyPondFile.LilyPondFile.file_initial_system_includes
   :noindex:

.. autoattribute:: abjad.tools.lilypondfiletools.LilyPondFile.LilyPondFile.file_initial_user_comments
   :noindex:

.. autoattribute:: abjad.tools.lilypondfiletools.LilyPondFile.LilyPondFile.file_initial_user_includes
   :noindex:

.. autoattribute:: abjad.tools.lilypondfiletools.LilyPondFile.LilyPondFile.items
   :noindex:

Read/write properties
---------------------

.. autoattribute:: abjad.tools.lilypondfiletools.LilyPondFile.LilyPondFile.default_paper_size
   :noindex:

.. autoattribute:: abjad.tools.lilypondfiletools.LilyPondFile.LilyPondFile.global_staff_size
   :noindex:

.. autoattribute:: abjad.tools.lilypondfiletools.LilyPondFile.LilyPondFile.use_relative_includes
   :noindex:

Special methods
---------------

.. automethod:: abjad.tools.lilypondfiletools.LilyPondFile.LilyPondFile.__eq__
   :noindex:

.. automethod:: abjad.tools.lilypondfiletools.LilyPondFile.LilyPondFile.__format__
   :noindex:

.. automethod:: abjad.tools.lilypondfiletools.LilyPondFile.LilyPondFile.__getitem__
   :noindex:

.. automethod:: abjad.tools.lilypondfiletools.LilyPondFile.LilyPondFile.__hash__
   :noindex:

.. automethod:: abjad.tools.lilypondfiletools.LilyPondFile.LilyPondFile.__illustrate__
   :noindex:

.. automethod:: abjad.tools.lilypondfiletools.LilyPondFile.LilyPondFile.__ne__
   :noindex:

.. automethod:: abjad.tools.lilypondfiletools.LilyPondFile.LilyPondFile.__repr__
   :noindex:
